var _default_vert = `
attribute vec4 a_position;
attribute vec2 a_texCoord;
attribute vec4 a_color;
varying vec2 v_texCoord;
varying vec4 v_fragmentColor;
void main()
{
    gl_Position = ( CC_PMatrix * CC_MVMatrix ) * a_position;
    v_fragmentColor = a_color;
    v_texCoord = a_texCoord;
}
`
var _default_vert_no_mvp = `
attribute vec4 a_position;
 attribute vec2 a_texCoord;
 attribute vec4 a_color;
 varying vec2 v_texCoord;
 varying vec4 v_fragmentColor;
 void main()
 {
     gl_Position = CC_PMatrix  * a_position;
     v_fragmentColor = a_color;
     v_texCoord = a_texCoord;
 }
`
var _defaulg_frag = `
#ifdef GL_ES
precision mediump float;
#endif
varying vec2 v_texCoord;

void main() {
    gl_FragColor = texture2D(CC_Texture0,v_texCoord);
}
`

cc.Class({
    extends: cc.Component,

    properties: {
        shader_frag_path: "default",
        _frag_glsl: "",
        _time: 0,
        _showTime : -1
    },

    onLoad: function () {
        if(this.shader_frag_path == "default") return;
        this.setGlsl(this.shader_frag_path);
    },
    update: function (dt) {
        if (this._program) {
            this._time += dt;
            if (cc.sys.isNative) {
                var glProgram_state = cc.GLProgramState.getOrCreateWithGLProgram(this._program);
                glProgram_state.setUniformFloat(this._iGlobalTime, this._time);//0.5
                if(this._showTime!=-1){
                    if(this._time>=this._showTime){
                        this._showTime = -1;
                        // this.setGlsl("default");
                        var s = this.getComponent(cc.Sprite);
                        s._sgNode.setState(0);
                    }
                }
            }
        }
    },
    setGlslWithTime:function(glsl,time){
        this._showTime = time;
        this.setGlsl(glsl);
    },
    setGlsl: function (glsl) {

        this.shader_frag_path = glsl;
        this._time = 0;
        var self = this;
        var path = "Shaders/"+this.shader_frag_path+".glsl";
        cc.log("glsl",path);
        cc.loader.loadRes(path, function (err, txt) {
            if (err) {
                cc.log(err)
            } else {
                self._frag_glsl = txt;
                self._use();
            }
        });
    },
    _use: function () {
        
        this._program = null;
        this._program = new cc.GLProgram();
        if (cc.sys.isNative) {
            cc.log("use native GLProgram")
            this._program.initWithString(_default_vert_no_mvp, this._frag_glsl);
            this._program.link();
            this._program.updateUniforms();
        } else {
            // this._program.initWithVertexShaderByteArray(_default_vert, this._frag_glsl);
            // this._program.addAttribute(cc.macro.ATTRIBUTE_NAME_POSITION, cc.macro.VERTEX_ATTRIB_POSITION);
            // this._program.addAttribute(cc.macro.ATTRIBUTE_NAME_COLOR, cc.macro.VERTEX_ATTRIB_COLOR);
            // this._program.addAttribute(cc.macro.ATTRIBUTE_NAME_TEX_COORD, cc.macro.VERTEX_ATTRIB_TEX_COORDS);
            // this._program.link();
            // this._program.updateUniforms();
        }

        

        if (cc.sys.isNative) {
            this._iGlobalTime = this._program.getUniformLocationForName("iGlobalTime");
            this._iResolutiion = this._program.getUniformLocationForName("iResolution");
            var glProgram_state = cc.GLProgramState.getOrCreateWithGLProgram(this._program);
            glProgram_state.setUniformFloat(this._iGlobalTime, 0.0);//0.5
            glProgram_state.setUniformVec2(this._iResolutiion, cc.p(this.node.getContentSize().width, this.node.getContentSize().height));//0.5
            var s = this.node.getComponent(cc.Sprite);
            if (s) {
                this.setProgram(s._sgNode, this._program);
            }
        } else {
            // this._program.setUniformLocationWith1f(this._iGlobalTime, 0.0);
            // this._program.setUniformLocationWith2f(this._iResolutiion, this.node.getContentSize().width, this.node.getContentSize().height);
        }
        
        
    },
    setProgram: function (node, program) {
        if (cc.sys.isNative) {
            var glProgram_state = cc.GLProgramState.getOrCreateWithGLProgram(program);
            node.setGLProgramState(glProgram_state);
        } else {
            node.setShaderProgram(program);
        }
    },
    onEnable: function () {

    },
});